@@ -6,11 +6,13 @@ import (
 	"path/filepath"
 	"strings"
 
+	"github.com/infracost/infracost/internal/apiclient"
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/output"
 	"github.com/infracost/infracost/internal/ui"
 	"github.com/mitchellh/go-homedir"
 	"github.com/pkg/errors"
+	log "github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 	"golang.org/x/mod/semver"
 )
@@ -33,12 +35,17 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 
   Merge multiple Infracost JSON files:
 
-      infracost output --format json --path "out*.json"`,
+      infracost output --format json --path "out*.json"
+
+  Create markdown report suitable for posting in a GitHub comment:
+
+      infracost output --format github-comment --path "out*.json"`,
 		ValidArgs: []string{"--", "-"},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			inputFiles := []string{}
 
 			paths, _ := cmd.Flags().GetStringArray("path")
+
 			for _, path := range paths {
 				expanded, err := homedir.Expand(path)
 				if err != nil {
@@ -85,6 +92,8 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 			}
 
 			format, _ := cmd.Flags().GetString("format")
+			ctx.SetContextValue("outputFormat", format)
+
 			includeAllFields := "all"
 			validFields := []string{"price", "monthlyQuantity", "unit", "hourlyCost", "monthlyCost"}
 
@@ -136,6 +145,9 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 				b, err = output.ToHTML(combined, opts)
 			case "diff":
 				b, err = output.ToDiff(combined, opts)
+			case "github-comment":
+				opts.IncludeHTML = true
+				b, err = output.ToMarkdown(combined, opts)
 			default:
 				b, err = output.ToTable(combined, opts)
 			}
@@ -143,20 +155,35 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 				return err
 			}
 
-			cmd.Println(string(b))
+			pricingClient := apiclient.NewPricingAPIClient(ctx.Config)
+			err = pricingClient.AddEvent("infracost-output", ctx.EventEnv())
+			if err != nil {
+				log.Errorf("Error reporting event: %s", err)
+			}
+
+			if outFile, _ := cmd.Flags().GetString("out-file"); outFile != "" {
+				err = saveOutFile(cmd, outFile, b)
+				if err != nil {
+					return err
+				}
+			} else {
+				cmd.Println(string(b))
+			}
 
 			return nil
 		},
 	}
 
 	cmd.Flags().StringArrayP("path", "p", []string{}, "Path to Infracost JSON files")
-	_ = cmd.MarkFlagRequired("path")
-	_ = cmd.MarkFlagFilename("path", "json")
+	cmd.Flags().StringP("out-file", "o", "", "Save output to a file, helpful with format flag")
 
-	cmd.Flags().String("format", "table", "Output format: json, diff, table, html")
+	cmd.Flags().String("format", "table", "Output format: json, diff, table, html, github-comment")
 	cmd.Flags().Bool("show-skipped", false, "Show unsupported resources, some of which might be free")
 	cmd.Flags().StringSlice("fields", []string{"monthlyQuantity", "unit", "monthlyCost"}, "Comma separated list of output fields: all,price,monthlyQuantity,unit,hourlyCost,monthlyCost.\nSupported by table and html output formats")
 
+	_ = cmd.MarkFlagRequired("path")
+	_ = cmd.MarkFlagFilename("path", "json")
+
 	_ = cmd.RegisterFlagCompletionFunc("format", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{"table", "json", "html"}, cobra.ShellCompDirectiveDefault
 	})
