@@ -1,6 +1,7 @@
 package main
 
 import (
+	"bytes"
 	"fmt"
 	"io"
 	"os"
@@ -33,6 +34,8 @@ func addRunFlags(cmd *cobra.Command) {
 	cmd.Flags().String("terraform-plan-flags", "", "Flags to pass to 'terraform plan'. Applicable when path is a Terraform directory")
 	cmd.Flags().String("terraform-workspace", "", "Terraform workspace to use. Applicable when path is a Terraform directory")
 
+	cmd.Flags().Bool("no-cache", false, "Don't attempt to cache Terraform plans")
+
 	cmd.Flags().Bool("show-skipped", false, "Show unsupported resources, some of which might be free")
 
 	cmd.Flags().Bool("sync-usage-file", false, "Sync usage-file with missing resources, needs usage-file too (experimental)")
@@ -106,7 +109,7 @@ func generateUsageFile(cmd *cobra.Command, runCtx *config.RunContext, projectCfg
 		}
 
 		spinner.Success()
-		cmd.Println(fmt.Sprintf("    %s Synced %d of %d resource%s",
+		cmd.PrintErrln(fmt.Sprintf("    %s Synced %d of %d resource%s",
 			ui.FaintString("└─"),
 			successes,
 			resources,
@@ -123,6 +126,10 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		ctx := config.NewProjectContext(runCtx, projectCfg)
 		runCtx.SetCurrentProjectContext(ctx)
 
+		for k, v := range projectCfg.Env {
+			os.Setenv(k, v)
+		}
+
 		provider, err := providers.Detect(ctx)
 		if err != nil {
 			m := fmt.Sprintf("%s\n\n", err)
@@ -216,7 +223,6 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 
 		providerProjects, err := provider.LoadResources(usageData)
 		if err != nil {
-			spinner.Fail()
 			return err
 		}
 
@@ -263,10 +269,12 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 
 	spinner.Success()
 
-	r := output.ToOutputFormat(projects)
-	r.Currency = runCtx.Config.Currency
+	r, err := output.ToOutputFormat(projects)
+	if err != nil {
+		return err
+	}
 
-	var err error
+	r.Currency = runCtx.Config.Currency
 
 	dashboardClient := apiclient.NewDashboardAPIClient(runCtx)
 	r.RunID, err = dashboardClient.AddRun(runCtx, projectContexts, r)
@@ -274,6 +282,35 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		log.Errorf("Error reporting run: %s", err)
 	}
 
+	opts := output.Options{
+		DashboardEnabled: runCtx.Config.EnableDashboard,
+		ShowSkipped:      runCtx.Config.ShowSkipped,
+		NoColor:          runCtx.Config.NoColor,
+		Fields:           runCtx.Config.Fields,
+	}
+
+	var b []byte
+
+	switch strings.ToLower(runCtx.Config.Format) {
+	case "json":
+		b, err = output.ToJSON(r, opts)
+	case "html":
+		b, err = output.ToHTML(r, opts)
+	case "diff":
+		b, err = output.ToDiff(r, opts)
+	default:
+		b, err = output.ToTable(r, opts)
+	}
+
+	if err != nil {
+		return errors.Wrap(err, "Error generating output")
+	}
+
+	if runCtx.Config.Format == "diff" || runCtx.Config.Format == "table" {
+		lines := bytes.Count(b, []byte("\n")) + 1
+		runCtx.SetContextValue("lineCount", lines)
+	}
+
 	env := buildRunEnv(runCtx, projectContexts, r)
 
 	pricingClient := apiclient.NewPricingAPIClient(runCtx.Config)
@@ -282,39 +319,20 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		log.Errorf("Error reporting event: %s", err)
 	}
 
-	opts := output.Options{
-		DashboardEnabled: runCtx.Config.EnableDashboard,
-		ShowSkipped:      runCtx.Config.ShowSkipped,
-		NoColor:          runCtx.Config.NoColor,
-		Fields:           runCtx.Config.Fields,
+	// Print a new line to separate the spinners from the output
+	if !runCtx.Config.IsLogging() {
+		cmd.PrintErrln()
 	}
 
-	var (
-		b   []byte
-		out string
-	)
-
-	switch strings.ToLower(runCtx.Config.Format) {
-	case "json":
-		b, err = output.ToJSON(r, opts)
-		out = string(b)
-	case "html":
-		b, err = output.ToHTML(r, opts)
-		out = string(b)
-	case "diff":
-		b, err = output.ToDiff(r, opts)
-		out = fmt.Sprintf("\n%s", string(b))
-	default:
-		b, err = output.ToTable(r, opts)
-		out = fmt.Sprintf("\n%s", string(b))
+	if outFile, _ := cmd.Flags().GetString("out-file"); outFile != "" {
+		err = saveOutFile(cmd, outFile, b)
+		if err != nil {
+			return err
+		}
+	} else {
+		cmd.Println(string(b))
 	}
 
-	if err != nil {
-		return errors.Wrap(err, "Error generating output")
-	}
-
-	cmd.Printf("%s\n", out)
-
 	return nil
 }
 
@@ -366,6 +384,8 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 		}
 	}
 
+	cfg.NoCache, _ = cmd.Flags().GetBool("no-cache")
+
 	cfg.Format, _ = cmd.Flags().GetString("format")
 	cfg.ShowSkipped, _ = cmd.Flags().GetBool("show-skipped")
 	cfg.SyncUsageFile, _ = cmd.Flags().GetBool("sync-usage-file")
@@ -433,9 +453,19 @@ func buildRunEnv(runCtx *config.RunContext, projectContexts []*config.ProjectCon
 	env["runSeconds"] = time.Now().Unix() - runCtx.StartTime
 	env["currency"] = runCtx.Config.Currency
 
+	usingCache := make([]bool, 0, len(projectContexts))
+	cacheErrors := make([]string, 0, len(projectContexts))
+	for _, pCtx := range projectContexts {
+		usingCache = append(usingCache, pCtx.UsingCache)
+		cacheErrors = append(cacheErrors, pCtx.CacheErr)
+	}
+	env["usingCache"] = usingCache
+	env["cacheErrors"] = cacheErrors
+
 	summary := r.FullSummary
 	env["supportedResourceCounts"] = summary.SupportedResourceCounts
 	env["unsupportedResourceCounts"] = summary.UnsupportedResourceCounts
+	env["noPriceResourceCounts"] = summary.NoPriceResourceCounts
 	env["totalSupportedResources"] = summary.TotalSupportedResources
 	env["totalUnsupportedResources"] = summary.TotalUnsupportedResources
 	env["totalNoPriceResources"] = summary.TotalNoPriceResources
