@@ -90,6 +90,8 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	GetWafv2WebACLRegistryItem(),
 	GetWafWebACLRegistryItem(),
 	GetStepFunctionRegistryItem(),
+	getDirectoryServiceDirectory(),
+	getTransferServerRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
@@ -341,6 +343,11 @@ var FreeResources = []string{
 	"aws_ssm_patch_group",
 	"aws_ssm_resource_data_sync",
 
+	// AWS Transfer Family
+	"aws_transfer_access",
+	"aws_transfer_ssh_key",
+	"aws_transfer_user",
+
 	// AWS VPC
 	"aws_customer_gateway",
 	"aws_default_network_acl",
