@@ -36,6 +36,7 @@ type DirProvider struct {
 	TerraformBinary     string
 	TerraformCloudHost  string
 	TerraformCloudToken string
+	Env                 map[string]string
 	cachedStateJSON     []byte
 	cachedPlanJSON      []byte
 }
@@ -64,6 +65,7 @@ func NewDirProvider(ctx *config.ProjectContext) schema.Provider {
 		TerraformBinary:     terraformBinary,
 		TerraformCloudHost:  ctx.ProjectConfig.TerraformCloudHost,
 		TerraformCloudToken: ctx.ProjectConfig.TerraformCloudToken,
+		Env:                 ctx.ProjectConfig.Env,
 	}
 }
 
@@ -172,6 +174,18 @@ func (p *DirProvider) generatePlanJSON() ([]byte, error) {
 		return p.cachedPlanJSON, nil
 	}
 
+	if UsePlanCache(p) {
+		spinner := ui.NewSpinner("Checking for cached plan...", p.spinnerOpts)
+		cached, err := ReadPlanCache(p)
+		if err != nil {
+			spinner.SuccessWithMessage(fmt.Sprintf("Checking for cached plan... %v", err.Error()))
+		} else {
+			p.cachedPlanJSON = cached
+			spinner.SuccessWithMessage("Checking for cached plan... found")
+			return p.cachedPlanJSON, nil
+		}
+	}
+
 	err := p.checks()
 	if err != nil {
 		return []byte{}, err
@@ -201,6 +215,10 @@ func (p *DirProvider) generatePlanJSON() ([]byte, error) {
 	j, err := p.runShow(opts, spinner, planFile)
 	if err == nil {
 		p.cachedPlanJSON = j
+		if UsePlanCache(p) {
+			// Note we check UsePlanCache again because we have discovered we're using remote execution inside p.runPlan
+			WritePlanCache(p, j)
+		}
 	}
 	return j, err
 }
@@ -236,6 +254,7 @@ func (p *DirProvider) buildCommandOpts(path string) (*CmdOptions, error) {
 		TerraformBinary:    p.TerraformBinary,
 		TerraformWorkspace: p.Workspace,
 		Dir:                path,
+		Env:                p.Env,
 	}
 
 	cfgFile, err := CreateConfigFile(p.Path, p.TerraformCloudHost, p.TerraformCloudToken)
@@ -464,6 +483,10 @@ func (p *DirProvider) printTerraformErr(err error) {
 		msg += "\nSpecify the -var-file flag as a path relative to your Terraform directory.\n"
 		msg += "For example: infracost --path=path/to/terraform --terraform-plan-flags=\"-var-file=my.tfvars\"\n"
 	}
+	if strings.HasPrefix(stderr, "Error: error configuring Terraform AWS Provider: no valid credential sources for Terraform AWS Provider found.") {
+		msg += "\nTerraform requires AWS credentials to be set.\n"
+		msg += "For more details, see https://registry.terraform.io/providers/hashicorp/aws\n"
+	}
 
 	fmt.Fprintln(os.Stderr, msg)
 }
